==> core-0.0.16-sources.jar: okw/seKeys.java <==
package okw;
import java.util.HashMap;
import org.openqa.selenium.Keys;
 
 
// http://blog.reallysimplethoughts.com/2013/09/25/using-special-keys-in-selenium-ide-part-2/
// http://www.abodeqa.com/tag/pressing-control-key-in-webdriver-using-action-builder-class-of-webdriver/
// https://seleniumhq.github.io/selenium/docs/api/java/org/openqa/selenium/Keys.html
public class seKeys {
 
        HashMap<String, Keys> keyName = new HashMap<String, Keys>();
               
        // Supported Modifier Keys
        seKeys(){
        
        keyName.put("KEY_ALT", Keys.ALT );
       
        keyName.put( "KEY_CONTROL", Keys.CONTROL);
        keyName.put( "KEY_CTRL", Keys.CONTROL);
       
        keyName.put( "KEY_META", Keys.COMMAND);
        keyName.put( "KEY_COMMAND", Keys.COMMAND);
                                       
        keyName.put( "KEY_SHIFT", Keys.SHIFT);
 
        // Supported Common Keys
        keyName.put( "KEY_BKSP", Keys.BACK_SPACE );
        keyName.put( "KEY_BACKSPACE", Keys.BACK_SPACE );
       
        keyName.put( "KEY_DEL", Keys.DELETE );
        keyName.put( "KEY_DELETE", Keys.DELETE );
       
        keyName.put( "KEY_ENTER", Keys.ENTER );
       
        keyName.put( "KEY_EQUALS", Keys.EQUALS );
       
        keyName.put( "KEY_ESC", Keys.ESCAPE );
        keyName.put( "KEY_ESCAPE", Keys.ESCAPE );
       
        keyName.put( "KEY_INS", Keys.INSERT );
        keyName.put( "KEY_INSERT", Keys.INSERT );
       
        keyName.put( "KEY_PAUSE", Keys.PAUSE );
        keyName.put( "KEY_SEMICOLON", Keys.SEMICOLON );
        keyName.put( "KEY_SPACE", Keys.SPACE );
        keyName.put( "KEY_TAB", Keys.TAB );
 
        // Supported Navigation Keys
        keyName.put( "KEY_LEFT", Keys.LEFT );
        keyName.put( "KEY_UP", Keys.UP );
        keyName.put( "KEY_RIGHT", Keys.RIGHT );
        keyName.put( "KEY_DOWN", Keys.DOWN );
       
        keyName.put( "KEY_PGUP", Keys.PAGE_UP );
        keyName.put( "KEY_PAGE_UP", Keys.PAGE_UP);
       
        keyName.put( "KEY_PGDN", Keys.PAGE_DOWN );
        keyName.put( "KEY_PAGE_DOWN", Keys.PAGE_DOWN );
       
        keyName.put( "KEY_END", Keys.END );
        keyName.put( "KEY_HOME", Keys.HOME );
 
        // Supported Number Pad Keys
        keyName.put( "KEY_NUMPAD0", Keys.NUMPAD0 );
        keyName.put( "KEY_N0", Keys.NUMPAD0 );
       
        keyName.put( "KEY_NUMPAD1", Keys.NUMPAD1 );
        keyName.put( "KEY_N1", Keys.NUMPAD0 );
       
        keyName.put( "KEY_NUMPAD2", Keys.NUMPAD2 );
        keyName.put( "KEY_N2", Keys.NUMPAD2 );
       
        keyName.put( "KEY_NUMPAD3", Keys.NUMPAD3 );
        keyName.put( "KEY_N3", Keys.NUMPAD3 );
       
        keyName.put( "KEY_NUMPAD4", Keys.NUMPAD4 );
        keyName.put( "KEY_N4", Keys.NUMPAD4 );
       
        keyName.put( "KEY_NUMPAD5", Keys.NUMPAD5 );
        keyName.put( "KEY_N5", Keys.NUMPAD5 );
       
        keyName.put( "KEY_NUMPAD6", Keys.NUMPAD6 );
        keyName.put( "KEY_N6", Keys.NUMPAD6 );
       
        keyName.put( "KEY_NUMPAD7", Keys.NUMPAD7 );
        keyName.put( "KEY_N7", Keys.NUMPAD7 );
       
        keyName.put( "KEY_NUMPAD8", Keys.NUMPAD8 );
        keyName.put( "KEY_N8", Keys.NUMPAD8 );
       
        keyName.put( "KEY_NUMPAD9", Keys.NUMPAD9 );
        keyName.put( "KEY_N9", Keys.NUMPAD9 );
       
        keyName.put( "KEY_ADD", Keys.ADD );
        keyName.put( "KEY_NUM_PLUS", Keys.ADD );
       
        keyName.put( "KEY_DECIMAL", Keys.DECIMAL );
        keyName.put( "KEY_NUM_PERIOD", Keys.DECIMAL );
       
        keyName.put( "KEY_DIVIDE", Keys.DIVIDE );
        keyName.put( "KEY_NUM_DIVISION", Keys.DIVIDE );
       
        keyName.put( "KEY_MULTIPLY", Keys.MULTIPLY );
        keyName.put( "KEY_NUM_MULTIPLY", Keys.MULTIPLY );
       
        keyName.put( "KEY_SEPARATOR", Keys.SEPARATOR );
        keyName.put( "KEY_SEP", Keys.SEPARATOR );
       
        keyName.put( "KEY_SUBTRACT", Keys.SUBTRACT );
        keyName.put( "KEY_NUM_MINUS", Keys.SUBTRACT );
 
        // Supported Function Keys
        keyName.put( "KEY_F1", Keys.F1 );
        keyName.put( "KEY_F2", Keys.F2 );
        keyName.put( "KEY_F3", Keys.F3 );
        keyName.put( "KEY_F4", Keys.F4 );
        keyName.put( "KEY_F5", Keys.F5 );
        keyName.put( "KEY_F6", Keys.F6 );
        keyName.put( "KEY_F7", Keys.F7 );
        keyName.put( "KEY_F8", Keys.F8 );
        keyName.put( "KEY_F9", Keys.F9 );
        keyName.put( "KEY_F10", Keys.F10 );
        keyName.put( "KEY_F11", Keys.F11 );
        keyName.put( "KEY_F12", Keys.F12 );
       
        };
}

==> core-0.0.28-sources.jar: okw/seKeys.java <==
package okw;
import java.util.HashMap;
//import org.openqa.selenium.Keys;
 
 
// http://blog.reallysimplethoughts.com/2013/09/25/using-special-keys-in-selenium-ide-part-2/
// http://www.abodeqa.com/tag/pressing-control-key-in-webdriver-using-action-builder-class-of-webdriver/
// https://seleniumhq.github.io/selenium/docs/api/java/org/openqa/selenium/Keys.html
public class seKeys {
 
/*        HashMap<String, Keys> keyName = new HashMap<String, Keys>();
               
        // Supported Modifier Keys
        seKeys(){
        
        keyName.put("KEY_ALT", Keys.ALT );
       
        keyName.put( "KEY_CONTROL", Keys.CONTROL);
        keyName.put( "KEY_CTRL", Keys.CONTROL);
       
        keyName.put( "KEY_META", Keys.COMMAND);
        keyName.put( "KEY_COMMAND", Keys.COMMAND);
                                       
        keyName.put( "KEY_SHIFT", Keys.SHIFT);
 
        // Supported Common Keys
        keyName.put( "KEY_BKSP", Keys.BACK_SPACE );
        keyName.put( "KEY_BACKSPACE", Keys.BACK_SPACE );
       
        keyName.put( "KEY_DEL", Keys.DELETE );
        keyName.put( "KEY_DELETE", Keys.DELETE );
       
        keyName.put( "KEY_ENTER", Keys.ENTER );
       
        keyName.put( "KEY_EQUALS", Keys.EQUALS );
       
        keyName.put( "KEY_ESC", Keys.ESCAPE );
        keyName.put( "KEY_ESCAPE", Keys.ESCAPE );
       
        keyName.put( "KEY_INS", Keys.INSERT );
        keyName.put( "KEY_INSERT", Keys.INSERT );
       
        keyName.put( "KEY_PAUSE", Keys.PAUSE );
        keyName.put( "KEY_SEMICOLON", Keys.SEMICOLON );
        keyName.put( "KEY_SPACE", Keys.SPACE );
        keyName.put( "KEY_TAB", Keys.TAB );
 
        // Supported Navigation Keys
        keyName.put( "KEY_LEFT", Keys.LEFT );
        keyName.put( "KEY_UP", Keys.UP );
        keyName.put( "KEY_RIGHT", Keys.RIGHT );
        keyName.put( "KEY_DOWN", Keys.DOWN );
       
        keyName.put( "KEY_PGUP", Keys.PAGE_UP );
        keyName.put( "KEY_PAGE_UP", Keys.PAGE_UP);
       
        keyName.put( "KEY_PGDN", Keys.PAGE_DOWN );
        keyName.put( "KEY_PAGE_DOWN", Keys.PAGE_DOWN );
       
        keyName.put( "KEY_END", Keys.END );
        keyName.put( "KEY_HOME", Keys.HOME );
 
        // Supported Number Pad Keys
        keyName.put( "KEY_NUMPAD0", Keys.NUMPAD0 );
        keyName.put( "KEY_N0", Keys.NUMPAD0 );
       
        keyName.put( "KEY_NUMPAD1", Keys.NUMPAD1 );
        keyName.put( "KEY_N1", Keys.NUMPAD0 );
       
        keyName.put( "KEY_NUMPAD2", Keys.NUMPAD2 );
        keyName.put( "KEY_N2", Keys.NUMPAD2 );
       
        keyName.put( "KEY_NUMPAD3", Keys.NUMPAD3 );
        keyName.put( "KEY_N3", Keys.NUMPAD3 );
       
        keyName.put( "KEY_NUMPAD4", Keys.NUMPAD4 );
        keyName.put( "KEY_N4", Keys.NUMPAD4 );
       
        keyName.put( "KEY_NUMPAD5", Keys.NUMPAD5 );
        keyName.put( "KEY_N5", Keys.NUMPAD5 );
       
        keyName.put( "KEY_NUMPAD6", Keys.NUMPAD6 );
        keyName.put( "KEY_N6", Keys.NUMPAD6 );
       
        keyName.put( "KEY_NUMPAD7", Keys.NUMPAD7 );
        keyName.put( "KEY_N7", Keys.NUMPAD7 );
       
        keyName.put( "KEY_NUMPAD8", Keys.NUMPAD8 );
        keyName.put( "KEY_N8", Keys.NUMPAD8 );
       
        keyName.put( "KEY_NUMPAD9", Keys.NUMPAD9 );
        keyName.put( "KEY_N9", Keys.NUMPAD9 );
       
        keyName.put( "KEY_ADD", Keys.ADD );
        keyName.put( "KEY_NUM_PLUS", Keys.ADD );
       
        keyName.put( "KEY_DECIMAL", Keys.DECIMAL );
        keyName.put( "KEY_NUM_PERIOD", Keys.DECIMAL );
       
        keyName.put( "KEY_DIVIDE", Keys.DIVIDE );
        keyName.put( "KEY_NUM_DIVISION", Keys.DIVIDE );
       
        keyName.put( "KEY_MULTIPLY", Keys.MULTIPLY );
        keyName.put( "KEY_NUM_MULTIPLY", Keys.MULTIPLY );
       
        keyName.put( "KEY_SEPARATOR", Keys.SEPARATOR );
        keyName.put( "KEY_SEP", Keys.SEPARATOR );
       
        keyName.put( "KEY_SUBTRACT", Keys.SUBTRACT );
        keyName.put( "KEY_NUM_MINUS", Keys.SUBTRACT );
 
        // Supported Function Keys
        keyName.put( "KEY_F1", Keys.F1 );
        keyName.put( "KEY_F2", Keys.F2 );
        keyName.put( "KEY_F3", Keys.F3 );
        keyName.put( "KEY_F4", Keys.F4 );
        keyName.put( "KEY_F5", Keys.F5 );
        keyName.put( "KEY_F6", Keys.F6 );
        keyName.put( "KEY_F7", Keys.F7 );
        keyName.put( "KEY_F8", Keys.F8 );
        keyName.put( "KEY_F9", Keys.F9 );
        keyName.put( "KEY_F10", Keys.F10 );
        keyName.put( "KEY_F11", Keys.F11 );
        keyName.put( "KEY_F12", Keys.F12 );
        };
*/
}
